@@ -29,6 +29,7 @@
 #include "Components/Converter/ConverterFactory.h"
 #include "Components/DynamicPlayback/DynamicPlaybackChecker.h"
 #include "Components/DynamicPlayback/DynamicPlaybackHandler.h"
+#include "Components/DynamicPlayback/LfmSimilarArtistFetcher.h"
 #include "Components/Engine/EngineHandler.h"
 #include "Components/Equalizer/Equalizer.h"
 #include "Components/LibraryManagement/LibraryManager.h"
@@ -41,7 +42,6 @@
 #include "Components/Playlist/PlaylistHandler.h"
 #include "Components/Playlist/PlaylistLibraryInteractor.h"
 #include "Components/Playlist/PlaylistLoader.h"
-#include "Components/RemoteControl/RemoteControl.h"
 #include "Components/Session/Session.h"
 #include "Components/Shutdown/Shutdown.h"
 #include "Components/SmartPlaylists/SmartPlaylistManager.h"
@@ -82,12 +82,12 @@
 #include "Gui/Preferences/Language/GUI_LanguagePreferences.h"
 #include "Gui/Preferences/LastFM/GUI_LastFmPreferences.h"
 #include "Gui/Preferences/Library/GUI_LibraryPreferences.h"
+#include "Gui/Preferences/Lyrics/GUI_LyricsPreferences.h"
 #include "Gui/Preferences/Notifications/GUI_NotificationPreferences.h"
 #include "Gui/Preferences/Player/GUI_PlayerPreferences.h"
 #include "Gui/Preferences/Playlist/GUI_PlaylistPreferences.h"
 #include "Gui/Preferences/PreferenceDialog/GUI_PreferenceDialog.h"
 #include "Gui/Preferences/Proxy/GUI_ProxyPreferences.h"
-#include "Gui/Preferences/RemoteControl/GUI_RemoteControlPreferences.h"
 #include "Gui/Preferences/Search/GUI_SearchPreferences.h"
 #include "Gui/Preferences/Shortcuts/GUI_ShortcutPreferences.h"
 #include "Gui/Preferences/StreamRecorder/GUI_StreamRecorderPreferences.h"
@@ -147,6 +147,7 @@ struct Application::Private
 {
 	Util::FileSystemPtr fileSystem;
 	Tagging::TagWriterPtr tagWriter;
+	WebClientFactoryPtr webClientFactory;
 	NotificationHandler* notificationHandler;
 	PlayManager* playManager;
 	Engine::Handler* engine;
@@ -165,7 +166,6 @@ struct Application::Private
 	GUI_Player* player {nullptr};
 	Dbus::SessionManager* dbusSessionManager {nullptr};
 	Library::LocalLibraryObserver* localLibraryWatcher {nullptr};
-	RemoteControl* remoteControl {nullptr};
 	InstanceThread* instanceThread {nullptr};
 
 	bool shutdownTriggered {false};
@@ -173,17 +173,22 @@ struct Application::Private
 	explicit Private(Application* app) :
 		fileSystem {Util::FileSystem::create()},
 		tagWriter(Tagging::TagWriter::create()),
+		webClientFactory(std::make_shared<WebClientFactory>()),
 		notificationHandler {NotificationHandler::create(app)},
 		playManager {PlayManager::create(notificationHandler, app)},
 		engine {new Engine::Handler(fileSystem, tagWriter, playManager)},
 		sessionManager {new Session::Manager(playManager)},
-		playlistHandler {new Playlist::Handler(playManager, std::make_shared<Playlist::LoaderImpl>())},
-		libraryPlaylistInteractor {LibraryPlaylistInteractor::create(playlistHandler, playManager)},
+		playlistHandler {new Playlist::Handler(playManager, std::make_shared<Playlist::LoaderImpl>(), fileSystem)},
+		libraryPlaylistInteractor {LibraryPlaylistInteractor::create(playlistHandler, playlistHandler, playManager)},
 		libraryManager {Library::Manager::create(libraryPlaylistInteractor)},
 		libraryPluginHandler {Library::PluginHandler::create()},
 		playlistLibraryInteractor {new Playlist::LibraryInteractor(libraryManager)},
 		dynamicPlaybackChecker {DynamicPlaybackChecker::create(libraryManager)},
-		dynamicPlaybackHandler {new DynamicPlayback::Handler(playManager, playlistHandler, playManager)},
+		dynamicPlaybackHandler {
+			new DynamicPlayback::Handler(playManager, playlistHandler,
+			                             std::make_shared<DynamicPlayback::LfmSimilarArtistFetcherFactory>(),
+			                             fileSystem, playManager)
+		},
 		smartPlaylistManager {new SmartPlaylistManager(playlistHandler, fileSystem)},
 		shutdown {Shutdown::create(playManager, notificationHandler)},
 		timer {Util::startMeasure()}
@@ -249,7 +254,6 @@ Application::~Application()
 		m->instanceThread = nullptr;
 	}
 
-	delete m->remoteControl;
 	delete m->localLibraryWatcher;
 	delete m->player;
 }
@@ -278,8 +282,6 @@ bool Application::init(const QStringList& filesToPlay, bool forceShow)
 	initPlayer(forceShow);
 	initDbusServices();
 
-	ListenSetting(Set::Remote_Active, Application::remoteControlActivated);
-
 	if(GetSetting(Set::Notification_Show))
 	{
 		m->notificationHandler->notify("Sayonara Player",
@@ -340,7 +342,7 @@ void Application::initDbusServices()
 	[[maybe_unused]] auto measureApp = Util::MeasureApp("Dbus services", m->timer);
 
 	new Dbus::Notifications(m->notificationHandler);
-	new Dbus::Mpris::MediaPlayer2(m->player, m->playManager, m->playlistHandler);
+	new Dbus::Mpris::MediaPlayer2(m->player, m->playManager, m->playlistHandler, m->fileSystem);
 	new Dbus::MediaKeysInterfaceGnome(m->playManager);
 	new Dbus::MediaKeysInterfaceMate(m->playManager);
 	m->dbusSessionManager = new Dbus::SessionManager(m->playManager);
@@ -371,19 +373,18 @@ void Application::initPreferences()
 	preferences->registerPreferenceDialog(new GUI_CoverPreferences("covers"));
 	preferences->registerPreferenceDialog(new GUI_EnginePreferences("engine"));
 	preferences->registerPreferenceDialog(new GUI_SearchPreferences("search"));
-
+	preferences->registerPreferenceDialog(new GUI_LyricsPreferences("lyrics"));
 	preferences->registerPreferenceDialog(new GUI_ProxyPreferences("proxy"));
 	preferences->registerPreferenceDialog(new GUI_StreamPreferences("streams"));
 	preferences->registerPreferenceDialog(new GUI_StreamRecorderPreferences("streamrecorder", m->fileSystem));
 	preferences->registerPreferenceDialog(new GUI_BroadcastPreferences("broadcast"));
-	preferences->registerPreferenceDialog(new GUI_RemoteControlPreferences("remotecontrol"));
 	preferences->registerPreferenceDialog(new GUI_OtherSettings("other-settings"));
 
 	auto* notificationPreferences = new GUI_NotificationPreferences("notifications", m->notificationHandler);
 	preferences->registerPreferenceDialog(notificationPreferences);
 
-	auto* lastFmPreferences =
-		new GUI_LastFmPreferences("lastfm", new LastFM::Base(m->playManager, m->notificationHandler));
+	auto* lastFm = new LastFM::Base(m->playManager, m->notificationHandler, m->webClientFactory);
+	auto* lastFmPreferences = new GUI_LastFmPreferences("lastfm", lastFm);
 	preferences->registerPreferenceDialog(lastFmPreferences);
 
 	preferences->registerPreferenceDialog(new GUI_FileExtensionPreferences("file-extensions"));
@@ -423,8 +424,7 @@ void Application::initPlugins()
 
 	auto* playerPluginHandler = PlayerPlugin::Handler::instance();
 
-	auto webClientFactory = std::make_shared<WebClientFactory>();
-	auto stationParserFactory = StationParserFactory::createStationParserFactory(webClientFactory, this);
+	auto stationParserFactory = StationParserFactory::createStationParserFactory(m->webClientFactory, this);
 	auto* streamHandler = new StreamHandler(m->playlistHandler, stationParserFactory);
 	auto* podcastHandler = new PodcastHandler(m->playlistHandler, stationParserFactory);
 
@@ -453,14 +453,6 @@ void Application::initSingleInstanceThread()
 	m->instanceThread->start();
 }
 
-void Application::remoteControlActivated()
-{
-	if(GetSetting(Set::Remote_Active) && !m->remoteControl)
-	{
-		m->remoteControl = new RemoteControl(m->playlistHandler, m->playManager, this);
-	}
-}
-
 void Application::createPlaylist()
 {
 	auto* instanceThread = dynamic_cast<InstanceThread*>(sender());
