@@ -294,10 +294,10 @@ namespace
 
 	int getBufferState(GstMessage* message)
 	{
-		auto percent = 0;
-		auto averageIn = 0;
-		auto averageOut = 0;
-		auto bufferingLeft = 0L;
+		gint percent = 0;
+		gint averageIn = 0;
+		gint averageOut = 0;
+		gint64 bufferingLeft = 0L;
 		auto bufferingMode = GstBufferingMode::GST_BUFFERING_STREAM;
 
 		gst_message_parse_buffering(message, &percent);
@@ -416,10 +416,10 @@ gboolean Callbacks::busStateChanged([[maybe_unused]] GstBus* bus, GstMessage* me
 			   !messageSourceName.contains("spectrum_sink") &&
 			   !messageSourceName.contains("pipeline"))
 			{
-				spLog(Log::Debug, ClassEngineCallbacks) << "EOF reached: " << messageSourceName;
 				break;
 			}
 
+			spLog(Log::Debug, ClassEngineCallbacks) << "EOF reached: " << messageSourceName;
 			engine->setTrackFinished(GST_ELEMENT(message->src));
 			break;
 
@@ -612,7 +612,8 @@ gboolean Callbacks::positionChanged(gpointer data)
 // dynamic linking, important for decodebin
 void Callbacks::decodebinReady(GstElement* source, GstPad* newSrcPad, gpointer data)
 {
-	const auto sourceName = EngineUtils::GStringAutoFree(gst_element_get_name(source)); // NOLINT(cppcoreguidelines-pro-type-cstyle-cast)
+	const auto sourceName = EngineUtils::GStringAutoFree(
+		gst_element_get_name(source)); // NOLINT(cppcoreguidelines-pro-type-cstyle-cast)
 	spLog(Log::Develop, "Callback") << "Source: " << sourceName.data();
 
 	auto* element = static_cast<GstElement*>(data);
@@ -627,7 +628,8 @@ void Callbacks::decodebinReady(GstElement* source, GstPad* newSrcPad, gpointer d
 		const auto padLinkReturn = gst_pad_link(newSrcPad, sinkPad);
 		if(padLinkReturn == GST_PAD_LINK_OK)
 		{
-			const auto elementName = EngineUtils::GStringAutoFree(gst_element_get_name(element)); // NOLINT(cppcoreguidelines-pro-type-cstyle-cast)
+			const auto elementName = EngineUtils::GStringAutoFree(
+				gst_element_get_name(element)); // NOLINT(cppcoreguidelines-pro-type-cstyle-cast)
 			spLog(Log::Develop, "Callbacks") << "Successfully linked " << sourceName.data()
 			                                 << " with " << elementName.data();
 		}
@@ -640,8 +642,9 @@ void Callbacks::decodebinReady(GstElement* source, GstPad* newSrcPad, gpointer d
 	gst_object_unref(sinkPad);
 }
 
-void Callbacks::sourceReady(GstURIDecodeBin* /* bin */, GstElement* source, gpointer /* data */)
+void Callbacks::sourceReady(GstURIDecodeBin* /* bin */, GstElement* source, gpointer data)
 {
+	auto* context = static_cast<TrackContext*>(data);
 	spLog(Log::Develop, "Engine Callback") << "Source ready: is soup? " << isSoupSource(source);
 	gst_base_src_set_dynamic_size(GST_BASE_SRC(source), false); // NOLINT(cppcoreguidelines-pro-type-cstyle-cast)
 
@@ -668,5 +671,12 @@ void Callbacks::sourceReady(GstURIDecodeBin* /* bin */, GstElement* source, gpoi
 				source,
 				"extra-headers", getSoundcloudOAuthStructure());
 		}
+
+		if(const auto userAgent = context->userAgent; !userAgent.isEmpty())
+		{
+			EngineUtils::setValues(
+				source,
+				"user-agent", userAgent.toLocal8Bit().constData());
+		}
 	}
 }
