@@ -29,7 +29,8 @@ class FMStreamSearcher :
 		using StationSearcher::StationSearcher;
 
 	protected:
-		[[nodiscard]] QString buildUrl(const QString& searchtext, Mode mode, int page, int maxEntries) const override;
+		[[nodiscard]] QString
+		buildUrl(const QString& searchtext, int serverIndex, Mode mode, int page, int maxEntries) const override;
 		[[nodiscard]] std::unique_ptr<StationParser> createStationParser() override;
 };
 
