@@ -35,7 +35,7 @@
 
 namespace
 {
-	constexpr const auto LatestDatabaseVersion = 35;
+	constexpr const auto LatestDatabaseVersion = 38;
 
 	bool updateAlbumCissearchFix(DB::Module& module, DB::LibraryDatabase& libraryDatabase)
 	{
@@ -142,6 +142,8 @@ namespace DB
 			return;
 		}
 
+		dropAllViews();
+
 		const auto currentVersion = currentDatabaseVersion();
 
 		auto libraryDatabase = LibraryDatabase {m->connectionName, m->databaseId, -1};
@@ -230,7 +232,7 @@ namespace DB
 
 		if(currentVersion < 6) // NOLINT(readability-magic-numbers)
 		{
-			const auto success = checkAndCreateTable("savedbookmarks", R"(CREATE TABLE savedbookmarks
+			const auto success = checkAndCreateTable("savedbookmarks", R"(CREATE TABLE savedbookmarks35
 			(
 				trackid INTEGER,
 				name VARCHAR(255),
@@ -720,6 +722,72 @@ namespace DB
 				settingsConnector.storeSetting("version", 35); // NOLINT(readability-magic-numbers)
 			}
 		}
+
+		/* 36 Could never succeed + 37 had no effect then */
+
+		if(const auto fix = 38; currentVersion < fix) // NOLINT(readability-magic-numbers)
+		{
+			checkAndInsertColumn("savedStreams", "userAgent", "VARCHAR(256)");
+			checkAndInsertColumn("savedPodcasts", "userAgent", "VARCHAR(256)");
+
+			auto success = checkIfTableExists("OnlineTracks");
+			if(!success)
+			{
+				db.transaction();
+
+				success = checkAndInsertColumn("playlistToTracks", "tempOnlineTrackId", "INTEGER");
+
+				auto fillTempTrackColumn = QSqlQuery(db);
+				fillTempTrackColumn.prepare("UPDATE playlistToTracks SET tempOnlineTrackId=rowID WHERE isRadio > 0;");
+				success &= fillTempTrackColumn.exec();
+
+				success &= checkAndCreateTable("OnlineTracks", R"(CREATE TABLE OnlineTracks
+				(
+					onlineTrackId INTEGER PRIMARY KEY,
+					stationName VARCHAR(512),
+					stationUrl VARCHAR(512),
+					radioMode INTEGER,
+					isUpdatable INTEGER DEFAULT 1,
+					userAgent VARCHAR(256),
+					description TEXT
+				);)");
+
+				auto createForeignKey = QSqlQuery(db);
+				createForeignKey.prepare(
+					R"(ALTER TABLE playlistToTracks
+					ADD COLUMN onlineTrackId INTEGER DEFAULT NULL
+					REFERENCES OnlineTracks(onlineTrackId) ON DELETE CASCADE;)");
+				success &= createForeignKey.exec();
+
+				auto migrationQuery = QSqlQuery(db);
+				migrationQuery.prepare(
+					R"(INSERT INTO OnlineTracks (onlineTrackId, stationName, stationUrl, radioMode, isUpdatable)
+					SELECT tempOnlineTrackId, stationName, station, isRadio, isUpdatable
+					FROM playlistToTracks WHERE station NOT NULL;)");
+				success &= migrationQuery.exec();
+
+				auto fillOnlineTrackIdColumn = QSqlQuery(db);
+				fillOnlineTrackIdColumn.prepare(
+					"UPDATE playlistToTracks SET onlineTrackId=tempOnlineTrackId WHERE isRadio > 0;");
+
+				success &= fillOnlineTrackIdColumn.exec();
+				success &= removeColumn("playlistToTracks", "tempOnlineTrackId");
+				if(success)
+				{
+					db.commit();
+				}
+
+				else
+				{
+					db.rollback();
+				}
+			}
+
+			if(success)
+			{
+				settingsConnector.storeSetting("version", fix); // NOLINT(readability-magic-numbers)
+			}
+		}
 	}
 
 	[[nodiscard]] int StandardConnectorFixes::currentDatabaseVersion() const
