@@ -23,7 +23,6 @@
 #include "FileListView.h"
 
 #include "Gui/Library/ui_GUI_DirectoryView.h"
-#include "Gui/Library/GUI_ImportDialog.h"
 
 #include "Components/LibraryManagement/LibraryManager.h"
 #include "Components/Library/LocalLibrary.h"
@@ -53,8 +52,51 @@ using Directory::FileListView;
 
 namespace
 {
-	QString copyOrMoveLibraryRequested(const Library::Info& libraryInfo, const QStringList& paths, QWidget* parent);
-	void showImageLabel(const QString& filename);
+	QString copyOrMoveLibraryRequested(const Library::Info& info, const QStringList& paths, QWidget* parent)
+	{
+		if(paths.isEmpty())
+		{
+			return {};
+		}
+
+		auto targetDirectory =
+			Gui::DirectoryChooser::getDirectory(QObject::tr("Choose target directory"), info.path(), true, parent);
+		if(targetDirectory.isEmpty())
+		{
+			return {};
+		}
+
+		const auto isSubDir = Util::File::isSubdir(targetDirectory, info.path());
+		const auto isSamePath = Util::File::isSamePath(targetDirectory, info.path());
+		if(!isSubDir && !isSamePath)
+		{
+			Message::error(QObject::tr("%1 is not a subdirectory of %2").arg(targetDirectory).arg(info.path()));
+			return {};
+		}
+
+		return targetDirectory;
+	}
+
+	void showImageLabel(const QString& filename)
+	{
+		constexpr const auto DefaultSize = 600;
+		const auto f = Util::File::getFilenameOfPath(filename);
+		const auto pm = QPixmap(filename);
+
+		auto* label = new QLabel();
+		label->setPixmap(pm);
+		label->setScaledContents(true);
+		label->setAttribute(Qt::WA_DeleteOnClose);
+		label->resize((DefaultSize * pm.width()) / pm.height(), DefaultSize);
+		label->setToolTip(QString("%1x%2").arg(pm.width()).arg(pm.height()));
+		label->setWindowTitle(QString("%1: %2x%3")
+			                      .arg(f)
+			                      .arg(pm.width())
+			                      .arg(pm.height())
+		);
+
+		label->show();
+	}
 }
 
 struct GUI_DirectoryView::Private
@@ -63,19 +105,15 @@ struct GUI_DirectoryView::Private
 	DirectorySelectionHandler* directorySelectionHandler;
 	QString filterTerm;
 
-	Private(Library::Manager* libraryManager) :
+	explicit Private(Library::Manager* libraryManager) :
 		libraryManager {libraryManager},
 		directorySelectionHandler {new DirectorySelectionHandler {libraryManager}} {}
 
-	Library::Info currentLibrary() const
-	{
-		return directorySelectionHandler->libraryInfo();
-	}
+	[[nodiscard]] Library::Info currentLibrary() const { return directorySelectionHandler->libraryInfo(); }
 };
 
 GUI_DirectoryView::GUI_DirectoryView(QWidget* parent) :
-	Gui::Widget(parent),
-	ui {nullptr} {}
+	Gui::Widget(parent) {}
 
 GUI_DirectoryView::~GUI_DirectoryView() = default;
 
@@ -100,22 +138,12 @@ void GUI_DirectoryView::initUi()
 	ui->tvDirs->init(m->libraryManager, info);
 	ui->lvFiles->init(m->libraryManager, info);
 
-	connect(m->directorySelectionHandler,
-	        &DirectorySelectionHandler::sigImportDialogRequested,
-	        this,
-	        &GUI_DirectoryView::importDialogRequested);
-	connect(m->directorySelectionHandler,
-	        &DirectorySelectionHandler::sigFileOperationStarted,
-	        this,
-	        &GUI_DirectoryView::fileOperationStarted);
-	connect(m->directorySelectionHandler,
-	        &DirectorySelectionHandler::sigFileOperationFinished,
-	        this,
-	        &GUI_DirectoryView::fileOperationFinished);
-	connect(m->directorySelectionHandler,
-	        &DirectorySelectionHandler::sigLibrariesChanged,
-	        this,
-	        &GUI_DirectoryView::load);
+	connect(m->directorySelectionHandler, &DirectorySelectionHandler::sigFileOperationStarted,
+	        this, &GUI_DirectoryView::fileOperationStarted);
+	connect(m->directorySelectionHandler, &DirectorySelectionHandler::sigFileOperationFinished,
+	        this, &GUI_DirectoryView::fileOperationFinished);
+	connect(m->directorySelectionHandler, &DirectorySelectionHandler::sigLibrariesChanged,
+	        this, &GUI_DirectoryView::load);
 
 	connect(ui->tvDirs, &QTreeView::pressed, this, &GUI_DirectoryView::dirPressed);
 	connect(ui->tvDirs, &TreeView::sigCurrentIndexChanged, this, &GUI_DirectoryView::dirClicked);
@@ -132,10 +160,8 @@ void GUI_DirectoryView::initUi()
 	connect(ui->tvDirs, &TreeView::sigRenameRequested, this, &GUI_DirectoryView::dirRenameRequested);
 	connect(ui->tvDirs, &TreeView::sigCopyToLibraryRequested, this, &GUI_DirectoryView::dirCopyToLibRequested);
 	connect(ui->tvDirs, &TreeView::sigMoveToLibraryRequested, this, &GUI_DirectoryView::dirMoveToLibRequested);
-	connect(ui->tvDirs->selectionModel(),
-	        &QItemSelectionModel::selectionChanged,
-	        this,
-	        &GUI_DirectoryView::dirSelectionChanged);
+	connect(ui->tvDirs->selectionModel(), &QItemSelectionModel::selectionChanged,
+	        this, &GUI_DirectoryView::dirSelectionChanged);
 
 	connect(ui->lvFiles, &QListView::pressed, this, &GUI_DirectoryView::filePressed);
 	connect(ui->lvFiles, &QListView::doubleClicked, this, &GUI_DirectoryView::fileDoubleClicked);
@@ -147,22 +173,14 @@ void GUI_DirectoryView::initUi()
 	connect(ui->lvFiles, &FileListView::sigPlayNewTabClicked, this, &GUI_DirectoryView::filePlayNewTabClicked);
 	connect(ui->lvFiles, &FileListView::sigDeleteClicked, this, &GUI_DirectoryView::fileDeleteClicked);
 	connect(ui->lvFiles, &FileListView::sigRenameRequested, this, &GUI_DirectoryView::fileRenameRequested);
-	connect(ui->lvFiles,
-	        &FileListView::sigRenameByExpressionRequested,
-	        this,
-	        &GUI_DirectoryView::fileRenameByExpressionRequested);
-	connect(ui->lvFiles,
-	        &FileListView::sigCopyToLibraryRequested,
-	        this,
-	        &GUI_DirectoryView::fileCopyToLibraryRequested);
-	connect(ui->lvFiles,
-	        &FileListView::sigMoveToLibraryRequested,
-	        this,
-	        &GUI_DirectoryView::fileMoveToLibraryRequested);
-	connect(ui->lvFiles->selectionModel(),
-	        &QItemSelectionModel::selectionChanged,
-	        this,
-	        &GUI_DirectoryView::fileSelectionChanged);
+	connect(ui->lvFiles, &FileListView::sigRenameByExpressionRequested,
+	        this, &GUI_DirectoryView::fileRenameByExpressionRequested);
+	connect(ui->lvFiles, &FileListView::sigCopyToLibraryRequested,
+	        this, &GUI_DirectoryView::fileCopyToLibraryRequested);
+	connect(ui->lvFiles, &FileListView::sigMoveToLibraryRequested,
+	        this, &GUI_DirectoryView::fileMoveToLibraryRequested);
+	connect(ui->lvFiles->selectionModel(), &QItemSelectionModel::selectionChanged,
+	        this, &GUI_DirectoryView::fileSelectionChanged);
 
 	connect(ui->splitter, &QSplitter::splitterMoved, this, &GUI_DirectoryView::splitterMoved);
 	connect(ui->btnCreateDir, &QPushButton::clicked, this, &GUI_DirectoryView::createDirectoryClicked);
@@ -171,7 +189,7 @@ void GUI_DirectoryView::initUi()
 	ui->tvDirs->setEnabled(false);
 	ui->tvDirs->setBusy(true);
 
-	QTimer::singleShot(500, this, &GUI_DirectoryView::load);
+	QTimer::singleShot(500, this, &GUI_DirectoryView::load); // NOLINT(*-magic-numbers)
 }
 
 void GUI_DirectoryView::load()
@@ -201,21 +219,6 @@ void GUI_DirectoryView::importRequested(LibraryId id, const QStringList& paths,
 	m->directorySelectionHandler->requestImport(id, paths, targetDirectory);
 }
 
-void GUI_DirectoryView::importDialogRequested(const QString& targetDirectory)
-{
-	if(!this->isVisible())
-	{
-		return;
-	}
-
-	auto* library = m->directorySelectionHandler->libraryInstance();
-	auto* importer = new GUI_ImportDialog(library, true, this);
-	connect(importer, &GUI_ImportDialog::sigClosed, importer, &GUI_ImportDialog::deleteLater);
-
-	importer->setTargetDirectory(targetDirectory);
-	importer->show();
-}
-
 void GUI_DirectoryView::newDirectoryClicked()
 {
 	const auto newDirName = Gui::LineInputDialog::getNewFilename(this, Lang::get(Lang::CreateDirectory));
@@ -256,9 +259,9 @@ void GUI_DirectoryView::dirEnterPressed()
 	}
 }
 
-void GUI_DirectoryView::dirOpened(QModelIndex idx)
+void GUI_DirectoryView::dirOpened(const QModelIndex& idx)
 {
-	const auto dir = (idx.isValid())
+	const auto dir = idx.isValid()
 	                 ? ui->tvDirs->directoryName(idx)
 	                 : m->currentLibrary().path();
 
@@ -273,10 +276,8 @@ void GUI_DirectoryView::dirOpened(QModelIndex idx)
 	m->directorySelectionHandler->libraryInstance()->fetchTracksByPath(dirs);
 }
 
-void GUI_DirectoryView::dirPressed(QModelIndex idx)
+void GUI_DirectoryView::dirPressed(const QModelIndex& /*idx*/)
 {
-	Q_UNUSED(idx)
-
 	const auto buttons = QApplication::mouseButtons();
 	if(buttons & Qt::MiddleButton)
 	{
@@ -290,7 +291,7 @@ void GUI_DirectoryView::dirSelectionChanged(const QItemSelection& selected, cons
 	ui->btnClearSelection->setVisible(!selected.isEmpty());
 }
 
-void GUI_DirectoryView::dirClicked(QModelIndex idx)
+void GUI_DirectoryView::dirClicked(const QModelIndex& idx)
 {
 	ui->lvFiles->clearSelection();
 
@@ -372,10 +373,8 @@ void GUI_DirectoryView::dirMoveToLibRequested(LibraryId libraryId)
 	}
 }
 
-void GUI_DirectoryView::filePressed(QModelIndex idx)
+void GUI_DirectoryView::filePressed(const QModelIndex& /*idx*/)
 {
-	Q_UNUSED(idx)
-
 	const auto buttons = QApplication::mouseButtons();
 	if(buttons & Qt::MiddleButton)
 	{
@@ -408,9 +407,8 @@ void GUI_DirectoryView::fileSelectionChanged(const QItemSelection& /*selected*/,
 	}
 }
 
-void GUI_DirectoryView::fileDoubleClicked(QModelIndex idx)
+void GUI_DirectoryView::fileDoubleClicked(const QModelIndex& /*idx*/)
 {
-	Q_UNUSED(idx)
 	fileEnterPressed();
 }
 
@@ -507,11 +505,8 @@ void GUI_DirectoryView::fileOperationFinished()
 	ui->lvFiles->setParentDirectory(ui->lvFiles->parentDirectory());
 }
 
-void GUI_DirectoryView::splitterMoved(int pos, int index)
+void GUI_DirectoryView::splitterMoved(const int /*pos*/, const int /*index*/)
 {
-	Q_UNUSED(pos)
-	Q_UNUSED(index)
-
 	SetSetting(Set::Dir_SplitterDirFile, ui->splitter->saveState());
 }
 
@@ -551,52 +546,3 @@ void GUI_DirectoryView::showEvent(QShowEvent* event)
 	initUi();
 	Gui::Widget::showEvent(event);
 }
-
-namespace
-{
-	QString copyOrMoveLibraryRequested(const Library::Info& info, const QStringList& paths, QWidget* parent)
-	{
-		if(paths.isEmpty())
-		{
-			return QString();
-		}
-
-		const auto targetDirectory =
-			Gui::DirectoryChooser::getDirectory(parent->tr("Choose target directory"), info.path(), true, parent);
-		if(targetDirectory.isEmpty())
-		{
-			return QString();
-		}
-
-		const auto isSubDir = Util::File::isSubdir(targetDirectory, info.path());
-		const auto isSamePath = Util::File::isSamePath(targetDirectory, info.path());
-		if(!isSubDir && !isSamePath)
-		{
-			Message::error(parent->tr("%1 is not a subdirectory of %2").arg(targetDirectory).arg(info.path()));
-			return QString();
-		}
-
-		return targetDirectory;
-	}
-
-	void showImageLabel(const QString& filename)
-	{
-		const auto f = Util::File::getFilenameOfPath(filename);
-		const auto pm = QPixmap(filename);
-
-		auto* label = new QLabel(nullptr);
-
-		label->setPixmap(pm);
-		label->setScaledContents(true);
-		label->setAttribute(Qt::WA_DeleteOnClose);
-		label->resize((600 * pm.width()) / pm.height(), 600);
-		label->setToolTip(QString("%1x%2").arg(pm.width()).arg(pm.height()));
-		label->setWindowTitle(QString("%1: %2x%3")
-			                      .arg(f)
-			                      .arg(pm.width())
-			                      .arg(pm.height())
-		);
-
-		label->show();
-	}
-}
