@@ -16,6 +16,8 @@
 #include "Gui/Utils/Widgets/FloatingLabel.h"
 #include "Gui/Utils/Widgets/RatingLabel.h"
 #include "Utils/Algorithm.h"
+#include "Utils/FileUtils.h"
+#include "Utils/Language/Language.h"
 #include "Utils/MetaData/MetaDataList.h"
 #include "Utils/Settings/Settings.h"
 #include "Utils/Utils.h"
@@ -29,12 +31,17 @@
 
 namespace
 {
-	QIcon widgetIcon(const Gui::Icons::IconName name)
+	[[nodiscard]] QString choose(const QString& str, const QString& alternative)
+	{
+		return str.isEmpty() ? alternative : str;
+	}
+
+	[[nodiscard]] QIcon widgetIcon(const Gui::Icons::IconName name)
 	{
 		using namespace Gui;
 
 		Icons::changeTheme();
-		return (Style::isDark())
+		return Style::isDark()
 		       ? Icons::icon(name, Icons::ForceSayonaraIcon)
 		       : Icons::icon(name, Icons::Automatic);
 	}
@@ -81,7 +88,7 @@ namespace
 	void setAlbumLabel(QLabel* label, QString album, const Year year)
 	{
 		const auto sYear = QString::number(year);
-		if(year > 1000 && (!album.contains(sYear))) // NOLINT(readability-magic-numbers)
+		if((year > 1000) && (!album.contains(sYear))) // NOLINT(readability-magic-numbers)
 		{
 			album += QString(" (%1)").arg(year);
 		}
@@ -112,17 +119,6 @@ namespace
 			label->setRating(rating);
 		}
 	}
-
-	void setWidgetsVisible(const QList<QWidget*>& widgets, const bool b)
-	{
-		for(auto* widget: widgets)
-		{
-			if(widget)
-			{
-				widget->setVisible(b);
-			}
-		}
-	}
 }
 
 struct GUI_ControlsBase::Private
@@ -192,7 +188,6 @@ void GUI_ControlsBase::currentTrackChanged(const MetaData& track)
 {
 	refreshCurrentPosition(0);
 	refreshLabels(track);
-
 	setCoverLocation(track);
 	setRadioMode(track.radioMode());
 
@@ -234,6 +229,7 @@ void GUI_ControlsBase::stopped()
 {
 	btnPlay()->setIcon(widgetIcon(Gui::Icons::Play));
 	labCurrentTime()->setText("00:00");
+	labMaxTime()->setText("00:00");
 	sliProgress()->setValue(0);
 
 	showTrackInfo(false);
@@ -285,12 +281,8 @@ void GUI_ControlsBase::refreshCurrentPosition(const int val)
 void
 GUI_ControlsBase::setTotalTimeLabel(const MilliSeconds totalTimeMs) // NOLINT(readability-make-member-function-const)
 {
-	if(totalTimeMs > 0)
-	{
-		const auto lengthStr = Util::msToString(totalTimeMs, "$M:$S");
-		labMaxTime()->setText(lengthStr);
-	}
-
+	const auto lengthStr = Util::msToString(totalTimeMs, "$M:$S");
+	labMaxTime()->setText(lengthStr);
 	labMaxTime()->setVisible(totalTimeMs > 0);
 	sliProgress()->setEnabled(totalTimeMs > 0);
 }
@@ -385,10 +377,7 @@ void GUI_ControlsBase::metadataChanged()
 
 void GUI_ControlsBase::showTrackInfo(const bool b) // NOLINT(readability-make-member-function-const)
 {
-	setWidgetsVisible(
-		{labTitle(), labArtist(), labAlbum(), widgetDetails(), labRating(), labCurrentTime(), labMaxTime()}, b);
-	setWidgetsVisible({labSayonara(), labCopyright(), labWrittenBy(), labVersion()}, !b);
-
+	showTrackInfoPage(b);
 	sliProgress()->setEnabled(b);
 }
 
@@ -401,9 +390,9 @@ void GUI_ControlsBase::refreshLabels(const MetaData& track)
 {
 	if(track.isValid())
 	{
-		setFloatingText(labTitle(), track.title());
-		setFloatingText(labArtist(), track.artist());
-		setAlbumLabel(labAlbum(), track.album(), track.year());
+		setFloatingText(labTitle(), choose(track.title(), MetaData::getTitleFromFilepath(track.filepath())));
+		setFloatingText(labArtist(), choose(track.artist(), Lang::get(Lang::UnknownArtist)));
+		setAlbumLabel(labAlbum(), choose(track.album(), Lang::get(Lang::UnknownAlbum)), track.year());
 		setBitrateLabel(labBitrate(), track.bitrate());
 		setFilesizeLabel(labFilesize(), track.filesize());
 		setRatingLabel(labRating(), track.rating(), track.radioMode());
@@ -516,20 +505,20 @@ void GUI_ControlsBase::setupShortcuts()
 	sch->shortcut(ShortcutIdentifier::Prev).connect(this, m->playManager, SLOT(previous()));
 	sch->shortcut(ShortcutIdentifier::VolDown).connect(this, m->playManager, SLOT(volumeDown()));
 	sch->shortcut(ShortcutIdentifier::VolUp).connect(this, m->playManager, SLOT(volumeUp()));
-	sch->shortcut(ShortcutIdentifier::SeekFwd).connect(this, [=]() {
+	sch->shortcut(ShortcutIdentifier::SeekFwd).connect(this, [&]() {
 		m->playManager->seekRelativeMs(SeekStep);
 	});
 
-	sch->shortcut(ShortcutIdentifier::SeekBwd).connect(this, [=]() {
+	sch->shortcut(ShortcutIdentifier::SeekBwd).connect(this, [&]() {
 		m->playManager->seekRelativeMs(-SeekStep);
 	});
 
-	sch->shortcut(ShortcutIdentifier::SeekFwdFast).connect(this, [=]() {
+	sch->shortcut(ShortcutIdentifier::SeekFwdFast).connect(this, [&]() {
 		const auto ms = m->playManager->durationMs() / 20;
 		m->playManager->seekRelativeMs(ms);
 	});
 
-	sch->shortcut(ShortcutIdentifier::SeekBwdFast).connect(this, [=]() {
+	sch->shortcut(ShortcutIdentifier::SeekBwdFast).connect(this, [&]() {
 		const auto ms = m->playManager->durationMs() / 20;
 		m->playManager->seekRelativeMs(-ms);
 	});
@@ -570,14 +559,10 @@ void GUI_ControlsBase::showEvent(QShowEvent* e)
 
 void GUI_ControlsBase::contextMenuEvent(QContextMenuEvent* e)
 {
+	using Library::ContextMenu;
 	if(!m->contextMenu)
 	{
-		using Library::ContextMenu;
-
 		m->contextMenu = new ContextMenu(this);
-		m->contextMenu->showActions(ContextMenu::EntryInfo |
-		                            ContextMenu::EntryLyrics |
-		                            ContextMenu::EntryEdit);
 
 		connect(m->contextMenu->action(ContextMenu::EntryInfo), &QAction::triggered, this, [&]() { showInfo(); });
 		connect(m->contextMenu->action(ContextMenu::EntryEdit), &QAction::triggered, this, [&]() { showEdit(); });
@@ -587,6 +572,22 @@ void GUI_ControlsBase::contextMenuEvent(QContextMenuEvent* e)
 		m->contextMenu->addPreferenceAction(new Gui::CoverPreferenceAction(m->contextMenu));
 	}
 
+	const auto currentTrack = m->playManager->currentTrack();
+	const auto isWWW = Util::File::isWWW(currentTrack.filepath());
+
+	int mask = 0;
+	if(currentTrack.isValid())
+	{
+		mask |= ContextMenu::EntryInfo;
+		mask |= ContextMenu::EntryLyrics;
+
+		if(!isWWW)
+		{
+			mask |= ContextMenu::EntryEdit;
+		}
+	}
+
+	m->contextMenu->showActions(mask);
 	m->contextMenu->exec(e->globalPos());
 }
 
