@@ -22,6 +22,7 @@
 #include "PlaylistModel.h"
 #include "PlaylistDelegate.h"
 #include "PlaylistContextMenu.h"
+#include "PlaylistCommandProcessor.h"
 #include "ContextMenuConfigurator.h"
 
 #include "Gui/Utils/GuiUtils.h"
@@ -77,7 +78,7 @@ namespace Playlist
 
 		int calcDragDropLine(const QPoint& pos, View* view)
 		{
-			const auto offset = (view->rowCount() > 0)
+			const auto offset = (view->model()->rowCount() > 0)
 			                    ? view->rowHeight(0) / 2
 			                    : view->fontMetrics().height() / 2;
 
@@ -87,7 +88,7 @@ namespace Playlist
 			}
 
 			const auto row = view->indexAt(pos).row();
-			return (row >= 0) ? row : view->rowCount() - 1;
+			return (row >= 0) ? row : view->model()->rowCount() - 1;
 		}
 
 		int resizeCoverSection(const int coverWidth, QHeaderView* horizontalHeader)
@@ -117,7 +118,7 @@ namespace Playlist
 		void initView(View* view, Model* model, Delegate* delegate, const int playlistIndex)
 		{
 			view->setObjectName(QString("playlist_view%1").arg(playlistIndex));
-			view->setSearchableModel(model);
+			view->setModel(model);
 			view->setItemDelegate(delegate);
 			view->setTabKeyNavigation(false);
 			view->setSelectionMode(QAbstractItemView::ExtendedSelection);
@@ -156,18 +157,20 @@ namespace Playlist
 		Model* model;
 		Gui::ProgressBar* progressbar;
 		QLabel* currentFileLabel;
+		CommandProcessor commandProcessor;
 
 		Private(const PlaylistPtr& playlist, DynamicPlaybackChecker* dynamicPlaybackChecker,
 		        Library::InfoAccessor* libraryAccessor, View* view) :
 			dynamicPlaybackChecker(dynamicPlaybackChecker),
 			model(new Model(playlist, libraryAccessor, view)),
 			progressbar(new Gui::ProgressBar(view)),
-			currentFileLabel(new QLabel(view)) {}
+			currentFileLabel(new QLabel(view)),
+			commandProcessor {view, model} {}
 	};
 
 	View::View(const PlaylistPtr& playlist, DynamicPlaybackChecker* dynamicPlaybackChecker,
 	           Library::InfoAccessor* libraryAccessor, QWidget* parent) :
-		SearchableTableView(parent),
+		SearchableTableView {parent},
 		Gui::Dragable(this)
 	{
 		m = Pimpl::make<Private>(playlist, dynamicPlaybackChecker, libraryAccessor, this);
@@ -234,7 +237,7 @@ namespace Playlist
 
 	void View::gotoRow(const int row)
 	{
-		if(Util::between(row, rowCount()))
+		if(Util::between(row, m->model->rowCount()))
 		{
 			const auto range = mapIndexToModelIndexes(row);
 			scrollTo(range.first);
@@ -349,9 +352,9 @@ namespace Playlist
 		m->model->removeTracks(selectedItems());
 		clearSelection();
 
-		if(rowCount() > 0)
+		if(m->model->rowCount() > 0)
 		{
-			const auto newRow = std::min(minRow, rowCount() - 1);
+			const auto newRow = std::min(minRow, m->model->rowCount() - 1);
 			selectRow(newRow);
 		}
 	}
@@ -416,12 +419,6 @@ namespace Playlist
 		}
 	}
 
-	void View::keyPressEvent(QKeyEvent* event)
-	{
-		event->setAccepted(false);
-		SearchableTableView::keyPressEvent(event);
-	}
-
 	void View::dragEnterEvent(QDragEnterEvent* event)
 	{
 		event->accept();
@@ -559,13 +556,13 @@ namespace Playlist
 		                           ? baseRowHeight + fm.height()
 		                           : baseRowHeight;
 
-		for(auto row = 0; row < rowCount(); row++)
+		for(auto row = 0; row < m->model->rowCount(); row++)
 		{
 			resizeSection(row, viewRowHeight, verticalHeader());
 		}
 
 		auto viewportWidth = viewport()->width();
-		viewportWidth -= resizeNumberSection(fm, rowCount(), horizontalHeader());
+		viewportWidth -= resizeNumberSection(fm, m->model->rowCount(), horizontalHeader());
 		viewportWidth -= resizeCoverSection(viewRowHeight, horizontalHeader());
 		viewportWidth -= resizeTimeSection(fm, horizontalHeader());
 
@@ -578,11 +575,17 @@ namespace Playlist
 		});
 	}
 
-	void View::searchDone()
+	SearchModel* View::searchModel() const { return m->model; }
+
+	void View::triggerResult()
 	{
 		if(GetSetting(Set::PL_PlayTrackAfterSearch))
 		{
 			playSelectedTrack();
 		}
 	}
+
+	QMap<QString, QString> View::commands() const { return m->commandProcessor.commands(); }
+
+	void View::runCommand(const QString& command) { m->commandProcessor.runCommand(command); }
 } // Playlist
