@@ -31,16 +31,16 @@ class GUI_StreamPreferences :
 	public Preferences::Base
 {
 	Q_OBJECT
-	UI_CLASS(GUI_StreamPreferences)
+	UI_CLASS_SHARED_PTR(GUI_StreamPreferences)
 
 	public:
-		GUI_StreamPreferences(const QString& identifier);
-		~GUI_StreamPreferences();
+		explicit GUI_StreamPreferences(const QString& identifier);
+		~GUI_StreamPreferences() override;
 
 		bool commit() override;
 		void revert() override;
 
-		QString actionName() const override;
+		[[nodiscard]] QString actionName() const override;
 
 	protected:
 		void initUi() override;
