@@ -26,12 +26,12 @@
 
 UI_FWD(GUI_CssEditor)
 
-class GUI_CssEditor : public
-	Gui::Dialog
+class GUI_CssEditor :
+	public Gui::Dialog
 {
-		Q_OBJECT
-		PIMPL(GUI_CssEditor)
-		UI_CLASS(GUI_CssEditor)
+	Q_OBJECT
+	UI_CLASS_SHARED_PTR(GUI_CssEditor)
+	PIMPL(GUI_CssEditor)
 
 	public:
 		explicit GUI_CssEditor(QWidget* parent = nullptr);
