@@ -39,8 +39,8 @@ namespace MetaDataSorting
 	namespace
 	{
 		template<typename Item, typename Fallback, typename Extractor>
-		bool compare(const Item& item1, const Item& item2, const SortModeMask sortMode, Fallback&& fallback,
-		             Extractor&& extractor)
+		bool compare(const Item& item1, const Item& item2, const SortModeMask sortMode, const Fallback& fallback,
+		             const Extractor& extractor)
 		{
 			const auto val1 = extractor(item1);
 			const auto val2 = extractor(item2);
@@ -58,8 +58,8 @@ namespace MetaDataSorting
 		}
 
 		template<typename Item, typename Fallback, typename Extractor>
-		bool compareRev(const Item& item1, const Item& item2, const SortModeMask sortMode, Fallback&& fallback,
-		                Extractor&& extractor)
+		bool compareRev(const Item& item1, const Item& item2, const SortModeMask sortMode, const Fallback& fallback,
+		                const Extractor& extractor)
 		{
 			const auto val1 = extractor(item1);
 			const auto val2 = extractor(item2);
@@ -105,7 +105,7 @@ namespace MetaDataSorting
 		QString convertString(QString str, const SortModeMask sortMode, const bool mayIgnoreArticle)
 		{
 			const auto searchModeMask = sortModeToSearchMode(sortMode);
-			if(mayIgnoreArticle && (sortMode & +SortMode::IgnoreArticle) && str.toLower().startsWith("the "))
+			if(mayIgnoreArticle && (sortMode & +SortMode::IgnoreArticle) && str.startsWith("the ", Qt::CaseInsensitive))
 			{
 				str = str.right(str.size() - 4);
 			}
@@ -193,6 +193,20 @@ namespace MetaDataSorting
 			});
 		}
 
+		bool TracksByGenresAsc(const MetaData& track1, const MetaData& track2, const SortModeMask sortMode)
+		{
+			return compare(track1, track2, sortMode, TracksByAlbumAsc, [&](const auto& track) {
+				return convertString(track.genresToList().join(", "), sortMode, true);
+			});
+		}
+
+		bool TracksByGenresDesc(const MetaData& track1, const MetaData& track2, const SortModeMask sortMode)
+		{
+			return compareRev(track2, track1, sortMode, TracksByGenresAsc, [&](const auto& track) {
+				return convertString(track.genresToList().join(", "), sortMode, true);
+			});
+		}
+
 		bool TracksByArtistAsc(const MetaData& track1, const MetaData& track2, const SortModeMask sortMode)
 		{
 			return compare(track1, track2, sortMode, TracksByAlbumAsc, [&](const auto& track) {
@@ -457,7 +471,7 @@ namespace MetaDataSorting
 		}
 
 		template<typename Container, typename FN>
-		void sort(Container& container, const SortModeMask sortMode, FN& fn)
+		void sort(Container& container, const SortModeMask sortMode, const FN& fn)
 		{
 			Util::Algorithm::sort(container, [&](const auto& c1, const auto& c2) {
 				return fn(c1, c2, sortMode);
@@ -559,6 +573,12 @@ namespace MetaDataSorting
 			case TrackSortorder::DateModifiedDesc:
 				sort(tracks, sortMode, TracksByModifiedDateDesc);
 				break;
+			case TrackSortorder::GenresAsc:
+				sort(tracks, sortMode, TracksByGenresAsc);
+				break;
+			case TrackSortorder::GenresDesc:
+				sort(tracks, sortMode, TracksByGenresDesc);
+				break;
 			default:
 				break;
 		}
