@@ -94,8 +94,11 @@ enum class SettingKey :
 	Lib_ColStateTracks,
 	Lib_CoverOrigPMCache,
 	Lib_CoverScaledPMCache,
+	Lib_CoverScrollspeed,
 	Lib_CoverShowArtist,
 	Lib_CoverShowUtils,
+	Lib_CoverShowYear,
+	Lib_CoverShowDuration,
 	Lib_CoverZoom,
 	Lib_CurPlugin,
 	Lib_DC_DoNothing,
@@ -128,6 +131,7 @@ enum class SettingKey :
 	Lib_UseViewClearButton,
 	Lib_ViewType,
 	Logger_Level,
+	Lyrics_ServerEntries,
 	Lyrics_Server,
 	Lyrics_Zoom,
 	MP3enc_found,
@@ -146,12 +150,14 @@ enum class SettingKey :
 	PL_LastTrack,
 	PL_LastTrackBeforeStop,
 	PL_LoadLastTrack,
+	PL_LoadRecentPlaylists,
 	PL_LoadSavedPlaylists,
 	PL_LoadTemporaryPlaylists,
 	PL_Mode,
 	PL_ModificatorAllowDynamicPlayback,
 	PL_ModificatorAllowRearrangeMethods,
 	PL_PlayTrackAfterSearch,
+	PL_RecentPlaylists,
 	PL_RememberTime,
 	PL_RememberTrackAfterStop,
 	PL_ShowBottomBar,
@@ -162,6 +168,7 @@ enum class SettingKey :
 	PL_SpecifyFileystemPlaylistName,
 	PL_StartPlaying,
 	PL_StartPlayingWorkaround_Issue263,
+	PL_StartAtRandomTrackOnShuffle,
 	PL_ShowConfirmationOnClose,
 	Pitch_found,
 	Player_514Fix,
@@ -190,10 +197,6 @@ enum class SettingKey :
 	Proxy_Port,
 	Proxy_SavePw,
 	Proxy_Username,
-	Remote_Active,
-	Remote_DiscoverPort,
-	Remote_Discoverable,
-	Remote_Port,
 	Settings_Revision,
 	Soundcloud_AuthToken,
 	Spectrum_Style,
@@ -235,6 +238,11 @@ namespace Library
 		quint8;
 }
 
+namespace Lyrics
+{
+	struct ServerEntry;
+}
+
 template<typename DataType, SettingKey keyIndex>
 struct SettingIdentifier
 {
@@ -318,7 +326,10 @@ namespace Set
 	CreateSetting(Lib_ColStateTracks, QByteArray); // Header state of tracks
 	CreateSetting(Lib_CoverOrigPMCache, int); // Original sized pixmap cache
 	CreateSetting(Lib_CoverScaledPMCache, int); // Scaled sized pixmap cache
+	CreateSetting(Lib_CoverScrollspeed, int); // Scrollspeed of cover view
 	CreateSetting(Lib_CoverShowArtist, bool); // Show artist name in cover view
+	CreateSetting(Lib_CoverShowYear, bool); // Show year in cover view
+	CreateSetting(Lib_CoverShowDuration, bool); // Show duration in cover view
 	CreateSetting(Lib_CoverShowUtils, bool); // Show utils bar in cover view
 	CreateSetting(Lib_CoverZoom, int); // Zoom of album cover view
 	CreateSetting(Lib_CurPlugin, QString); // Current shown library plugin
@@ -352,7 +363,8 @@ namespace Set
 	CreateSetting(Lib_UseViewClearButton, bool); // Show clear button in single view
 	CreateSetting(Lib_ViewType, Library::ViewType); // Standard view, CoverView, LibraryView
 	CreateSetting(Logger_Level, int); // Also log development:
-	CreateSetting(Lyrics_Server, QString); // Lyrics server
+	CreateSetting(Lyrics_ServerEntries, QList<Lyrics::ServerEntry>); // disabled lyrics servers
+	CreateSetting(Lyrics_Server, QString); // Last used lyrics server
 	CreateSetting(Lyrics_Zoom, int); // Zoom factor in lyrics window
 	CreateSetting(Notification_Name, QString); // type of notifications: libnotify or empty for native baloons
 	CreateSetting(Notification_Show, bool); // show notifications
@@ -372,10 +384,12 @@ namespace Set
 	CreateSetting(PL_CreateFilesystemPlaylist, bool); // create an extra playlist when loading files from file system
 	CreateSetting(PL_SpecifyFileystemPlaylistName, bool); // when creating playlist from files, choose special name
 	CreateSetting(PL_FilesystemPlaylistName, QString); // name of the file system playlist
+	CreateSetting(PL_LoadRecentPlaylists, bool); // load recent playlists
 	CreateSetting(PL_Mode, Playlist::Mode); // playlist mode: rep1, repAll, shuffle...
 	CreateSetting(PL_ModificatorAllowDynamicPlayback, bool);
 	CreateSetting(PL_ModificatorAllowRearrangeMethods, bool);
 	CreateSetting(PL_PlayTrackAfterSearch, bool); // play track after search is done
+	CreateSetting(PL_RecentPlaylists, QList<int>);
 	CreateSetting(PL_RememberTime, bool); // remember time of last track
 	CreateSetting(PL_RememberTrackAfterStop, bool); // when stop button is pressed, remember last track index
 	CreateSetting(PL_ShowBottomBar, bool); // Show bottom bar in playlist
@@ -383,6 +397,7 @@ namespace Set
 	CreateSetting(PL_ShowCovers, bool); // Show covers in Playlist
 	CreateSetting(PL_ShowNumbers, bool); // show numbers in playlist
 	CreateSetting(PL_ShowRating, bool); // Show rating in playlist
+	CreateSetting(PL_StartAtRandomTrackOnShuffle, bool); // start randomly when playlist in shuffle mode
 	CreateSetting(PL_StartPlaying, bool); // start playing immediately when opening Sayonara
 	CreateSetting(PL_StartPlayingWorkaround_Issue263, bool); // issue #263
 	CreateSetting(PL_ShowConfirmationOnClose, bool);
@@ -412,10 +427,6 @@ namespace Set
 	CreateSetting(Proxy_Port, int); // Proxy Port 3128
 	CreateSetting(Proxy_SavePw, bool); // Should password be saved
 	CreateSetting(Proxy_Username, QString); // Proxy Username
-	CreateSetting(Remote_Active, bool); // Remote control activated
-	CreateSetting(Remote_DiscoverPort, int); // UDP port for remote discovering
-	CreateSetting(Remote_Discoverable, bool); // broadcast is discoverable via UDP
-	CreateSetting(Remote_Port, int); // Remote control port
 	CreateSetting(Settings_Revision, int); // Version number of settings
 	CreateSetting(Spectrum_Style, int); // index of spectrum style
 	CreateSetting(Speed_LastTab, int); // Last tab selected int he speed/pitch plugin
