@@ -29,6 +29,7 @@
 #include "Utils/Library/Sorting.h"
 #include "Utils/Library/LibraryInfo.h"
 #include "Utils/Library/LibraryNamespaces.h"
+#include "Utils/LyricServerEntry.h"
 
 #include "Utils/RawShortcutMap.h"
 
@@ -110,8 +111,11 @@ bool SettingRegistry::init()
 	registerSetting<Set::Lib_CoverZoom>("lib_cover_zoom", 100); // NOLINT(readability-magic-numbers)
 	registerSetting<Set::Lib_CoverShowUtils>("lib_cover_show_utils", false);
 	registerSetting<Set::Lib_CoverShowArtist>("lib_cover_show_artist", true);
+	registerSetting<Set::Lib_CoverShowYear>("lib_cover_show_year", false);
+	registerSetting<Set::Lib_CoverShowDuration>("lib_cover_show_duration", false);
 	registerSetting<Set::Lib_CoverOrigPMCache>("lib_cover_orig_pm_cache", 1);
 	registerSetting<Set::Lib_CoverScaledPMCache>("lib_cover_scaled_pm_cache", 3);
+	registerSetting<Set::Lib_CoverScrollspeed>("lib_cover_scrollspeed", -1);
 	registerSetting<Set::Lib_GenreTree>("lib_show_genre_tree", true);
 	registerSetting<Set::Lib_LastIndex>("lib_last_idx", -1);
 	registerSetting<Set::Lib_AllLibraries>("lib_all_libraries", {}); // deprecated
@@ -163,9 +167,11 @@ bool SettingRegistry::init()
 	registerSetting<Set::Player_PublicId>("player_pub_id", {});
 	registerSetting<Set::Player_ForceNativeDirDialog>("player_native_dir_dialog", false);
 
+	registerSetting<Set::PL_LoadRecentPlaylists>("load_recent_playlists", true);
 	registerSetting<Set::PL_LoadSavedPlaylists>("load_saved_playlists", false);
-	registerSetting<Set::PL_LoadTemporaryPlaylists>("load_temporary_playlists", true);
+	registerSetting<Set::PL_LoadTemporaryPlaylists>("load_temporary_playlists", false);
 	registerSetting<Set::PL_LoadLastTrack>("load_last_track", true);
+	registerSetting<Set::PL_RecentPlaylists>("playlist_recent_session", {});
 	registerSetting<Set::PL_RememberTime>("remember_time", true);
 	registerSetting<Set::PL_StartPlaying>("start_playing", false);
 	registerSetting<Set::PL_StartPlayingWorkaround_Issue263>("start_playing_wa_263", false);
@@ -192,6 +198,7 @@ bool SettingRegistry::init()
 	registerSetting<Set::PL_ShowConfirmationOnClose>("playlist_confirm_on_close", false);
 	registerSetting<Set::PL_ModificatorAllowDynamicPlayback>("playlist_allow_dyn_playback_on_lock", false);
 	registerSetting<Set::PL_ModificatorAllowRearrangeMethods>("playlist_allow_rearrange_on_lock", false);
+	registerSetting<Set::PL_StartAtRandomTrackOnShuffle>("playlist_start_at_random_track", false);
 	registerSetting<Set::Notification_Show>("show_notifications", true);
 	registerSetting<Set::Notification_Timeout>("notification_timeout", 5000); // NOLINT(readability-magic-numbers)
 	registerSetting<Set::Notification_Name>("notification_name", {"DBus"});
@@ -236,11 +243,6 @@ bool SettingRegistry::init()
 	registerSetting<Set::Broadcast_Prompt>("broadcast_prompt", false);
 	registerSetting<Set::Broadcast_Port>("broadcast_port", 54054); // NOLINT(readability-magic-numbers)
 
-	registerSetting<Set::Remote_Active>("remote_control_active", false);
-	registerSetting<Set::Remote_Port>("remote_control_port", {54055}); // NOLINT(readability-magic-numbers)
-	registerSetting<Set::Remote_Discoverable>("remote_discoverable", false);
-	registerSetting<Set::Remote_DiscoverPort>("remote_discoverport", 54056); // NOLINT(readability-magic-numbers)
-
 	registerSetting<Set::Stream_NewTab>("stream_new_tab", true);
 	registerSetting<Set::Stream_ShowHistory>("stream_show_history", true);
 	registerSetting<Set::Stream_SearchWindowSize>("stream_search_window_size", {});
@@ -249,6 +251,7 @@ bool SettingRegistry::init()
 	registerSetting<Set::Stream_RadioSearcherType>("stream_radio_searcher_type", 0); // by name
 	registerSetting<Set::Stream_LockedPlaylistByDefault>("stream_locked_playlist", true);
 
+	registerSetting<Set::Lyrics_ServerEntries>("lyric_server_entries", {});
 	registerSetting<Set::Lyrics_Server>("lyrics_server", {});
 	registerSetting<Set::Lyrics_Zoom>("lyrics_zoom", 100); // NOLINT(readability-magic-numbers)
 
